@@ -32,6 +32,7 @@
 #include <unique/uniqueapp.h>
 
 #include "gvc-mixer-dialog.h"
+#include "gvc-log.h"
 
 #define GVCA_DBUS_NAME "org.gnome.VolumeControl"
 #define DIALOG_POPUP_TIMEOUT 3
@@ -146,6 +147,8 @@ main (int argc, char **argv)
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
         textdomain (GETTEXT_PACKAGE);
 
+	gvc_log_init ();
+
         error = NULL;
         gtk_init_with_args (&argc, &argv,
                             (char *) _(" - GNOME Volume Control"),
@@ -161,6 +164,8 @@ main (int argc, char **argv)
                 exit (1);
         }
 
+	gvc_log_set_debug (debug);
+
         app = unique_app_new (GVCA_DBUS_NAME, NULL);
         if (unique_app_is_running (app)) {
                 unique_app_send_message (app, UNIQUE_ACTIVATE, NULL);
